
/*****
Code for Chapter 4 analysis, Bubbles and Crashes, Goldfarb and Kirsch (2019)
Code implement judgment calls made by authors with consideration of the history

Telephone appears on the generated graph, and is missing from graph in book, due to minor coding error.

*/
set more off
clear

****NOTES
*The following items have  been reverse coded vis a vis the original coding document: 
*B2B/B2C
*pureplay*/
*Business model obviousness is reverse coded*/
*enforcement of isolating mechanisms reverse coded*/
*Control of IP and C.A. coded on 1-3 scale, also reverse coded*/
*isolating mechanisms coded*/
*Ultimate success reverse coded*/

***Novice rating is based on the period, per the text in the book
*g novicerating = 1 
*replace novicerating = 9 if 1925<=BubOpE  & 1929>= BubOpS
*replace novicerating = 9 if 1955<=BubOpE  & 1972>= BubOpS
*replace novicerating = 9 if 1880<=BubOpE  & 1890>= BubOpE

***CODE STARTS HERE:



use BaCCh4Data, clear

xtile CtrlUnc = ctrlun, nquantiles(3)
xtile techbizunc =  techbizValChainun, nquantiles(3)
xtile narrativebin =  narrative, nquantiles(3)
label var CtrlUnc "Control uncertainty terciles"
label var techbizunc "Technology Biz Uncertainty terciles"
label var narrativebin "Narrative uncertainty terciles"

g novice = 3*(novicerating==9) + 1*(novicerating==1)
label var novice "Novices in market"
drop novicerating

label def lmh 1 "low" 2 "medium" 3 "high"
label values  CtrlUnc techbizunc narrativebin novice lmh 
label def yn 1 "yes" 0 "no"
label values atrisk presbub yn


/*Radar was not coded properly by the RAs - so it is done here. 
Radar was  a wartime technology developed with heavy government intervention and 
hence did not follow a standard commercialization path. There was very little uncertainty 
regarding its development and commercialization patterns
There is not a full coding set for Radar, but its history is straighforward */

replace CtrlUnc = 1 if tech == "Radar"
replace techbizunc = 1 if tech == "Radar"
replace narrativebin = 1 if tech == "Radar"
replace novice = 3 if tech == "Radar"


*Corrective Coding:
***Student coding led to too narrow a view at times. Authors recoded based on their understanding of the historical record
 replace CtrlUnc = 3 if tech == "Internal Combustion" /*RAs viewed IC patents as more powerful than they were (also not on the IC engine) */
 replace techbizunc = 3 if tech == "Incandescent Lamp" /*5-pager does not consider the lack of understanding of business model early on*/
 replace CtrlUnc = 3 if tech == "Am Radio" /*Sarnoff sits at center stage, but radio patents were difficult to enfouce*/
 replace narrativebin = 3 if tech == "Am Radio" /*See book*/
 replace techbizunc = 1 if tech == "synthetic rubber" /*Rubber manufacturers were able to transition with no difficulty*/
 replace CtrlUnc = 1  if tech == "Insulin" /*The control of the technology was well enforced by Univ of Toronto & Ely Lilly*/
 replace CtrlUnc = 1  if tech == "FM Radio" /*FM radio was different than AM, as it it extended existing complementary assets*/
 replace narrativebin = 3 if tech == "Jet Engine" /*The Jet engine narrative was caught up in the missile race and cold war*/
 replace CtrlUnc = 1 if tech == "Silicone" /*This was never coded by the RAs, but the supply of the tech was  controlled by Dow Corning as they had strong patent protection. Silicon is a chemical - this is not referring to transistors!*/
 replace techbizunc = 3 if tech == "Phototype" /*phototype new and enabled new things (like desktop publishing), and hence changed the biz model*/ 
 replace CtrlUnc = 3 if tech == "Phototype" /*The technology was also commercialized by numerous players - patent protection was not strong enought to keep players out*/
 replace CtrlUnc = 2 if tech == "Long Playing Record" /*So there was no control over the record, but production was controlled by the labels and the complementary assets kept small producers out, this is a marginal coding decision, and could be set to 3*/	
 replace techbizunc = 3 if tech == "Transistor" /*It wasn't clear what it would be used for .. i.e., the original applications.*/ 
 replace CtrlUnc = 3 if tech == "Transistor" /*Due to the consent decree, effectively no firm had control over the transistor (Bell Labs licensed it out to all comers for $25K). This fact was missed in the original coding*/
replace narrativebin = 2 if tech == "Transistor" /*The low tech score does not match the excitement about electronics. So the question becomes should we view this as the "transistor" or "electronics". Probably more historically accurate to think of it as electronics*/
replace narrativebin = 3 if tech == "Wankel Motor" /*The Wankel motor narrative was extraordinary (see book, Chapter 5)*/
replace techbizunc = 3 if tech == "Telephone" /*There was great uncertainty about how the business model would work, See book, various chapters*/
replace CtrlUnc = 2 if tech == "Television" /*Certainly there was no control over production of the television, but there was significantly less uncertainty about the broadcast component - thus it was less uncertain than Radio in the 1920s, and requires a lower score*/ 
replace novice = 1 if tech == "Television" /*This is entirely due to timing,we have a low novice score in teh 1940s and 1950s*/
replace techbizunc = 2 if tech == "Television" /*There was lower uncertainty in the business of television because of the precedent of radio. */


g factors = CtrlUnc + techbizunc + narrativebin + novice
label var factors "Cumulative score of bubble risk factors, scale 4-12"
 ***to make readible graphs
 
 sort atrisk factors tech
 bys atrisk factors: gen order = _n
 capture drop froth_art
 
 **froth_art is used to position labels and make the graphs labels not overlap
 
 by atrisk factors: gen froth_art =  (-_N/2+order)*.12  
 label var froth_art "Graphical positioning technologies without investment targets"
 
 g pos = 12
 replace pos = 12 if factors ==12 & atrisk ==1
 label var pos "clockwise position of the label in graph"
 capture drop factors2

g factors2 = factors - 4
label var factors2 "factors scale to 0-8, 8 is most likely to lead to bubble"
gen tech2 = tech

*Make labels a bit prettier
replace tech2 = "Cont. Cracking" if tech == "Continuous CatalyticThermal Cra" 
replace tech2 = "Cont. Hot Strip Rolling" if regexm(tech, "(Hot Strip)")
replace tech2 = strproper(tech2)
***strproper is not one size fits all:
replace tech2 = "DDT" if tech2 == "Ddt"
replace tech2 = "AM Radio" if tech2 == "Am Radio"
replace tech2 = "FM Radio" if tech2 == "Fm Radio"
label var tech2 "Technology name"
label var tech "Technology name, less pretty"



 
 ***Adjustments for pretty graph
 
 capture drop froth_art2
 g froth_art2 = froth_art/5.9
  replace froth_art2 = froth_art2-0.13 
  capture drop factors3
  
  ***Move far right items on graph slightly left for better fit.
  ***factors 3 is for graphing purposes only.
  g factors3 = factors2
    replace factors3 = 7.85 if regexm(lower(tech2),"(oil|am radio|aviation)")
  format %2.1f Fall 
  twoway scatter Fall factors3 if atrisk==1, msize(tiny) mlab(tech2) mlabsize(tiny) mlabp(3) /*
 */mcolor(gs0) msymbol(i) mlabvpos(pos) ylabel(0(.1)1) ytitle("Percentage Fall Peak to Trough") xtitle("factors") legend(off)|| /*
 */scatter froth_art2 factors3 /*
 */ if atrisk==0 , msize(vtiny) mlab(tech2) mlabsize(tiny) mlabp(3)  /*
 */ mcolor(gs9) mlabang(0) msymbol(i) mlabpos(0)  ylabel(0(.1)1) legend(off) xtitle("factors") yline(0, lp(dash))
graph export BaC_figure4_1.png, width(800) height(600) replace
graph save BaC_figure4_1, replace


tabstat factors2, by(atrisk) st(mean)

 ***Mean values
 tabstat atrisk  firstappearance BubOpS BubOpE  CtrlUnc  techbizunc  narrativebin  novice factors2 Bubble Frothiness Fall Relative_Fall Bubble_Date , st(mean) by(tech2)

 **IS there a correlation between uncertainty and having pureplay investment opportunities?
 **PResumably yes, because then we get more entrepreneurial firms
g totunc = CtrlUnc +techbizunc
pwcorr atrisk totunc

pwcorr Frothiness Fall factors2 if atrisk==1, sig
capture drop factors2wreg
***See if regulation matters. First, crude low reg pre 1933, high after (Glass Steagal). 
g factors2wreg = factors2 + 2*(BubOpE<=1933)
pwcorr Frothiness factors2wreg if atrisk==1, sig

***See if it matters if we add slightly more fine tuned regulatory regimes.
*** Low regulation prior to 1913 (+2 to factor scale)
****moderate through 1933 (+1 to factor scale
****high after 1933 (+0 to factor scale)
g factors2wreg3 = factors2 + 2*(BubOpE<=1913)+ 1*( (BubOpE<=1933)& (BubOpE>1913))
pwcorr Frothiness factors2wreg3 if atrisk==1, sig
***No meaningful effect on inference.
 
*** 
 rename factors2 Factors
 ***Export data for tables
gsort -atrisk Factors BubOpS
export excel  using "BaC_Ch4_Data", first(var) replace
export excel tech2 techbizunc CtrlUnc narrativebin presbub novice b2b atrisk Frothiness Bubble_Date first BubOpS BubOpE using "BaC_Ch4TableA1", firstrow(var) replace

log using Ch4_Codebook, replace text
codebook
log close 
